# make-gif

Make gif from images.

## Install

    pip install makegif

## Installed Commands

- makegif

## Help

    D:\code\make-gif>makegif --help
    Usage: makegif [OPTIONS] [IMAGE_FOLDER]

    Make gif from images.

    Options:
    -o, --output TEXT     Output image path.  [required]
    -d, --duration FLOAT  Gap time between frames.
    --help                Show this message and exit.

## Examples

    D:\code\make-gif>makegif -o test.gif test

